.. _routines.random:

Random sampling (:mod:`numpy.random`)
*************************************

.. currentmodule:: numpy.random

Simple random data
==================
.. autosummary::
   :toctree: generated/

   rand
   randn
   randint
   random_integers
   random_sample
   random
   ranf
   sample
   choice
   bytes

Permutations
============
.. autosummary::
   :toctree: generated/

   shuffle
   permutation

Distributions
=============
.. autosummary::
   :toctree: generated/

   beta
   binomial
   chisquare
   dirichlet
   exponential
   f
   gamma
   geometric
   gumbel
   hypergeometric
   laplace
   logistic
   lognormal
   logseries
   multinomial
   multivariate_normal
   negative_binomial
   noncentral_chisquare
   noncentral_f
   normal
   pareto
   poisson
   power
   rayleigh
   standard_cauchy
   standard_exponential
   standard_gamma
   standard_normal
   standard_t
   triangular
   uniform
   vonmises
   wald
   weibull
   zipf

Random generator
================
.. autosummary::
   :toctree: generated/

   RandomState
   seed
   get_state
   set_state
